.. _interleaved:

====================
Interleaved beamlets
====================

PySight allows you to de-multiplex images generated by
interleaving more than one excitation beam. For example,
assuming a laser reprate of 80 MHz, sometimes you may wish
to create two beamlets out of the main excitation beam,
and space them 6.25 ns apart so that every 6.25 ns a new
pulse hits the sample and excites the fluorophores in it.
This method is very useful for numerous imaging techniques,
but is usually very hard to implement, requiring top-of-the-
line electronics and high expertise.

.. note:: You must connect the laser clock to the multiscaler
    in order to use this option.

By marking the ``Interleave?`` checkbox in the *Advanced*
part of the GUI, you notify PySight that two (and currenlty
**only** two) beams were interleaved. PySight then knows to
divide the photons arriving at the detector into two parts,
generating two different stacks of images in its output files.

